import { useEffect, useLayoutEffect, useState } from 'react';
import { Layout, LoginWrapper, MainLayout } from '../layout/UserLayout';
import LoginForm from './Login';
import { useUserStore } from '../store';
import { useShallow } from 'zustand/react/shallow';
import { Suspense } from 'react';

export const Login = () => {
  const userStore = useUserStore(
    useShallow((state) => {
      return {
        config: state.config,
        setConfig: state.setConfig,
        loadedConfig: state.loadedConfig,
        setLoadedConfig: state.setLoadedConfig,
        queryCheck: state.queryCheck,
      };
    }),
  );
  useLayoutEffect(() => {
    fetchConfig();
    userStore.queryCheck();
  }, []);
  const fetchConfig = async () => {
    try {
      const res = await fetch('./config.js');
      const configScript = await res.text();
      const blob = new Blob([configScript], { type: 'application/javascript' });
      const moduleUrl = URL.createObjectURL(blob);
      const module = await import(/* @vite-ignore */ moduleUrl);
      URL.revokeObjectURL(moduleUrl); // Clean up the object URL
      userStore.setConfig(module.config);
    } catch (error) {
      console.error('Failed to load config:', error);
    }
  };

  return (
    <Suspense fallback={<div></div>}>
      {userStore.loadedConfig ? (
        <LoginWrapper>
          <LoginForm />
        </LoginWrapper>
      ) : (
        <div>Loading...</div>
      )}
    </Suspense>
  );
};
