import { useUserStore, Config } from '@/user/store';
import { useShallow } from 'zustand/shallow';
import QRCode, { QRCodeToDataURLOptions } from 'qrcode';
import { message } from '@/modules/message';
import { useEffect, useRef, useState } from 'react';
import { query, queryLogin } from '@/modules/query';
const useCreateLoginQRCode = (config: Config) => {
  const url = new URL(window.location.href);
  const redirect = url.searchParams.get('redirect');
  const loginSuccessUrl = config.loginSuccess;
  const redirectURL = redirect ? decodeURIComponent(redirect) : loginSuccessUrl;
  var opts: QRCodeToDataURLOptions = {
    errorCorrectionLevel: 'H',
    type: 'image/jpeg',
    margin: 1,
    width: 300,
  };
  const [state, setState] = useState('');
  let timer = useRef<any>(null);
  const loginUrl = config?.wxmpLogin?.loginUrl || '';
  if (!loginUrl) {
    message.error('没有配置微信登陆配置');
    return;
  }
  const createQrcode = async (state: string) => {
    const text = `${loginUrl}?state=${state}`;
    var img = document.getElementById('qrcode')! as HTMLCanvasElement;
    // img.src = url;
    const res = await QRCode.toDataURL(img, text, opts);
  };
  const checkLogin = async (state: string) => {
    const res = await fetch(`/api/router?path=wx&key=checkLogin&state=${state}`).then((res) => res.json());
    if (res.code === 200) {
      console.log(res);
      const token = res.data;
      if (token) {
        localStorage.setItem('token', token.accessToken);
        await queryLogin.setLoginToken(token);
      }
      setTimeout(() => {
        window.location.href = redirectURL;
      }, 1000);
    } else {
      timer.current = setTimeout(() => {
        checkLogin(state);
      }, 2000);
    }
  };
  useEffect(() => {
    // 随机生成一个state
    const state = Math.random().toString(36).substring(2, 15);
    createQrcode(state);
    checkLogin(state);
    const timer2 = setInterval(() => {
      const state = Math.random().toString(36).substring(2, 15);
      clearTimeout(timer.current); // 清除定时器
      createQrcode(state); // 90秒后更新二维码
      checkLogin(state);
    }, 90000);
    return () => {
      clearInterval(timer.current);
      clearInterval(timer2);
    };
  }, []);
  return { createQrcode };
};
export const WeChatMpLogin = () => {
  const userStore = useUserStore(
    useShallow((state) => {
      return { config: state.config! };
    }),
  );
  useCreateLoginQRCode(userStore.config);

  return (
    <div>
      <canvas id='qrcode' width='300' height='300'></canvas>
    </div>
  );
};
